
# Class: Target


Path for output to be saved.

URI: [https://w3id.org/neat/Target](https://w3id.org/neat/Target)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Target&#124;target_path:string%20%3F])](https://yuml.me/diagram/nofunky;dir:TB/class/[Target&#124;target_path:string%20%3F])

## Attributes


### Own

 * [➞target_path](target__target_path.md)  <sub>0..1</sub>
     * Description: File path for saving results.
     * Range: [String](types/String.md)
